#  BEEN: Benchmarking Environment
#  ==============================
#
#  File author: Jakub Lehotsky
#
#  GNU Lesser General Public License Version 2.1
#  ---------------------------------------------
#  Copyright (C) 2004-2006 Distributed Systems Research Group,
#  Faculty of Mathematics and Physics, Charles University in Prague
#
#  This library is free software; you can redistribute it and/or
#  modify it under the terms of the GNU Lesser General Public
#  License version 2.1, as published by the Free Software Foundation.
#
#  This library is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#  Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public
#  License along with this library; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
#  MA  02111-1307  USA

# Note: these functions are documented in .hlp files, that come together with whole R package, and
#		can be browsed via BEEN UI. See BEEN web packages for more R packages to download


xampler.generateExperimentGraph <- function (aid, eid, valid = TRUE) {
	write("Generating rubis experiment graph...", file=stdout());
	
	# rubis contains single binary only
	bid <- base.listBinaries(aid, eid)[1];
	
	write(bid,file=stdout());
	

	
	hostCount <- base.getHostCount(aid, eid);
	data <- base.loadRunData(aid, eid, bid, 0, 0, 0);
	columnCount = dim(data)[1];
	
	if (is.na(dim(data)[2])) {
	  columnCount = 1;
    }
	
	if (hostCount == 1) {
		graphsFile <- paste(base.getDatabaseRoot(), "/", aid, "/", eid, "/results.graphs", sep="");
			
		if (file.exists(graphsFile)) {
			file.remove(graphsFile);
		}

		for (column in (1:columnCount)-1) {
		
			first = TRUE;
			
			labels = character(0);
		
			for (bid in base.listBinaries(aid, eid)) {

				statsFile  <- paste(base.getDatabaseRoot(), "/", aid, "/", eid, "/", bid,
						"/statistics", column, "-0.table", sep="");

				maxRun = base.getValidRunsCount(aid, eid, bid)
				runCount = base.getRunsCount(aid, eid, bid);						
				
				if (first) {
								
					m <- matrix(nrow = runCount, ncol = 5);
					m = read.table(file = statsFile);
					
					for (run in 1:runCount) {
						labels = c(labels, paste(bid, " / ", run, sep=""));
					}
					
					first = FALSE;
					
					write(dim(m), file=stdout());
					
				} else {
				
				    m2 <- matrix(nrow = runCount, ncol = 5);
				    m2 = read.table(file = statsFile);
				    m <- rbind(m, m2);

					for (run in 1:runCount) {
						labels = c(labels, paste(bid, " / ", run,sep=""));
					}
				    
				    write(dim(m), file=stdout());
				}
				
			}
	
			toPlot <- vector();
			toPlot <- m[,1];
		
			graphDirectory <- paste(base.getDatabaseRoot(), "/", aid, "/", eid, sep="");
			graphFilename <- paste("graph", column, ".png", sep="");
		
			base.generateOneColoredGraph(graphsFile, column, graphDirectory, graphFilename, toPlot, 
				graphTitle = paste("Xampler all binaries run averages - column ", column, sep=""),
				 vertLabel = "Runs", horLabel = "Average time/1000 ticks", color="blue", grHeight = 250,
				 graphLabels = labels);
		}
	} else {
	
		graphsFile <- paste(base.getDatabaseRoot(), "/", aid, "/", eid, "/results.graphs", sep="");
			
		if (file.exists(graphsFile)) {
			file.remove(graphsFile);
		}

		maxRun = base.getValidRunsCount(aid, eid, bid)
		
		for (column in (1:columnCount)-1) {
		
			plotMatrix <- matrix(nrow = maxRun, ncol = hostCount);
		
			for (host in (1:hostCount)-1) {

				first = TRUE;
			
				labels = character(0);
				
			
				for (bid in base.listBinaries(aid, eid)) {

					statsFile  <- paste(base.getDatabaseRoot(), "/", aid, "/", eid, "/", bid,
							"/statistics", column, "-", host, ".table", sep="");

					maxRun = base.getValidRunsCount(aid, eid, bid)
					runCount = base.getRunsCount(aid, eid, bid);						

						
					if (first) {
									
						m <- matrix(nrow = base.getRunsCount(aid, eid, bid), ncol = 5);
						m = read.table(file = statsFile)
						
						for (run in 1:runCount) {
							labels = c(labels, paste(bid, " / ", run, sep=""));
						}
					
						first = FALSE;
					
					} else {
					
					    m2 <- matrix(nrow = base.getRunsCount(aid, eid, bid), ncol = 5);
					    m2 = read.table(file = statsFile)
					    m <- rbind(m, m2);
					    
					 	for (run in 1:runCount) {
							labels = c(labels, paste(bid, " / ", run,sep=""));
						}
				    
					}
				
				}
				
		
				plotMatrix[,host+1] <- m[,1];
								 				
			}
			
			graphDirectory <- paste(base.getDatabaseRoot(), "/", aid, "/", eid, sep="");
			graphFilename <- paste("graph", column, ".png", sep="");	
			
			hostLegends <- c(base.getHost(aid, eid, 0));

			if (hostCount>1) {
				for (host in (2:hostCount)-1) {
					hostLegends <- c(hostLegends, base.getHost(aid, eid, host));
				}
			}
			
			write(paste(hostLegends), file=stderr());			
			
			base.generateMultiColoredGraph(graphsFile, column, graphDirectory, graphFilename, plotMatrix, 
				graphTitle = paste("Column \"", column, "\"", sep=""),					
				 graphLabels = labels, vertLabel = "Runs", horLabel = "Average time/microsecs", legends = hostLegends);
			
		}
	}
		
}

xampler.generateRegressionAnalysisGraph <- function (aid, eid, valid = TRUE) {
# takes unused parameter eid - required by experiment callbacks (no analysis
# callbacks exist

    expCount <- base.getExperimentsCount(aid)
    
    if (expCount < 2) {
    	#at least two experiments to generate analysis graph    	
    	return ()
    }
    
    if (!base.isRegressionAnalysis(aid)) {
		return ();
	}

	firstExp = TRUE;

	for (eid in base.listExperiments(aid)) {
	
		hostCount <- base.getHostCount(aid, eid);
		
		a <- numeric(0);
		
		first = TRUE;
		
		for (host in (1:hostCount)-1) {
			expStatFile <- paste(base.getDatabaseRoot(), "/", aid, "/", eid, "/experiment-table0-", 
					host, ".value", sep="");
#			write(expStatFile, file=stderr());
			value = read.table(file = expStatFile);
#			write(dim(value), file=stderr());
			if (first) {
				a <- value[1,];
				first = FALSE; 
			} else {
#				write(c(a), file=stderr());
				a <- c(a, value[1,]);
			}
			
			hostsAvg = mean(a);
			
		}
		
		if (firstExp) {

			exp <- hostsAvg;
			firstExp = FALSE;			
			expNames <- base.getExperimentName(aid, eid);
			
		} else {
			exp <- c(exp, hostsAvg);
			expNames <- c(expNames, base.getExperimentName(aid, eid));
		}
		
	}
	
	write(exp, file=stderr());
	write(expNames, file=stderr());
	
	graphsFile <- paste(base.getDatabaseRoot(), "/", aid, "/results.graphs", sep="");
	
	if (file.exists(graphsFile)) {
		file.remove(graphsFile);
	}
	
	graphDirectory <- paste(base.getDatabaseRoot(), "/", aid, sep="");
	graphFilename <- paste("graph0.png", sep="");	
	
	base.generateOneColoredGraph(graphsFile, 0, graphDirectory, graphFilename, exp, 
		 graphTitle = "Xampler experiments comparison", horLabel = "Average time/1000s tick", 
		 color="red", grWidth=550, grHeight=500, graphLabels = expNames, regr = TRUE);
	
	
	#draw experiments graph
	
	return ();
}
