/*
 *  BEEN: Benchmarking Environment
 *  ==============================
 *
 *  File author: Michal Tomcanyi
 *
 *  GNU Lesser General Public License Version 2.1
 *  ---------------------------------------------
 *  Copyright (C) 2004-2006 Distributed Systems Research Group,
 *  Faculty of Mathematics and Physics, Charles University in Prague
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License version 2.1, as published by the Free Software Foundation.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 *  MA  02111-1307  USA
 */
package cz.cuni.mff.been.benchmarkmanager;

import java.rmi.RemoteException;

import cz.cuni.mff.been.common.ComponentInitializationException;
import cz.cuni.mff.been.task.Service;
import cz.cuni.mff.been.task.TaskException;
import cz.cuni.mff.been.task.TaskInitializationException;

/**
 * The Benchmark Manager service class.
 * 
 * @author David Majda
 * @author Michal Tomcanyi
 */
public class BenchmarkManagerService extends Service {
	/** Name of the service. */
	public static final String SERVICE_NAME = "benchmarkmanager";
	/** Human-readable name of the service (displayed in the web interface). */
	public static final String SERVICE_HUMAN_NAME = "Benchmark Manager";

	private BenchmarkManager implementation;

	public BenchmarkManagerService() throws TaskInitializationException {
		/* Create the implementation. */
		try {
			implementation = BenchmarkManager.getInstance();
		} catch (RemoteException e) {
			throw new TaskInitializationException(e);
		} catch (ComponentInitializationException e) {
			throw new TaskInitializationException(e);
		}

		/* Register implemented interface. */
		addRemoteInterface(RMI_MAIN_IFACE, implementation);
	}

	/**
	 * @see cz.cuni.mff.been.task.Service#getName()
	 */
	@Override
	public String getName() {
		return SERVICE_NAME;
	}

	public void stopService() throws RemoteException, TaskException {
		getControlInterface().stopService();
	}
	
	
	/**
	 * @see cz.cuni.mff.been.task.Service#start()
	 */
	@Override
	protected void start() throws TaskException {
	}

	/**
	 * @see cz.cuni.mff.been.task.Service#stop()
	 */
	@Override
	protected void stop() throws TaskException {
	}
}
