/*
 *  BEEN: Benchmarking Environment
 *  ==============================
 *
 *  File author: Michal Tomcanyi
 *
 *  GNU Lesser General Public License Version 2.1
 *  ---------------------------------------------
 *  Copyright (C) 2004-2006 Distributed Systems Research Group,
 *  Faculty of Mathematics and Physics, Charles University in Prague
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License version 2.1, as published by the Free Software Foundation.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 *  MA  02111-1307  USA
 */
package cz.cuni.mff.been.benchmarkmanager;

import org.xml.sax.Attributes;
import org.xml.sax.InputSource;
import org.xml.sax.SAXException;
import org.xml.sax.helpers.DefaultHandler;

import cz.cuni.mff.been.benchmarkmanager.plugins.PluginEntityResolver;

/**
 * SAX parser adapter which extracts basic information about benchmark plugin
 * from its XML configuration
 */

public class ConfigParserAdapter extends DefaultHandler {

	/* elements */
	private static final String ELEMENT_BENCHMARK = "benchmark";
	private static final String ELEMENT_DESCRIPTION = "description";
	
	/* attributes */
	private static final String BENCHMARK_NAME = "name";
	private static final String BENCHMARK_VERSION = "version";
	
	
	// flag indicating whether we are parsing inside
	// Benchmark.XML_DESCIRPTION_ELEM
	private boolean descActive = false;

	// fields will be filled from XML
	private StringBuffer benchmarkName = new StringBuffer();

	private StringBuffer benchmarkVersion = new StringBuffer();

	private StringBuffer benchmarkDescription = new StringBuffer();

	private PluginEntityResolver resolver;
	
	private ConfigParserAdapter() {
		
	}
	
	public ConfigParserAdapter(String baseURI) {
		super();
		this.resolver = new PluginEntityResolver(baseURI);
	}
	
	/**
	 * Method processes benchmark and description elements, all the others are
	 * ignored.
	 */
	public void startElement(String uri, String localName, String qName,
			Attributes atts) throws SAXException {
		if (qName.equals(ELEMENT_BENCHMARK)) {
			benchmarkName.append(atts.getValue(BENCHMARK_NAME));
			benchmarkVersion.append(atts.getValue(BENCHMARK_VERSION));
		} else if (qName.equals(ELEMENT_DESCRIPTION)) {
			descActive = true;
		}
	}

	public void characters(char[] ch, int start, int length)
			throws SAXException {
		if (descActive) {
			benchmarkDescription.append(ch, start, length);
		}
	}

	public void reset() {
		this.benchmarkName.delete(0, benchmarkName.length());
		this.benchmarkVersion.delete(0, benchmarkName.length());
		this.benchmarkDescription.delete(0, benchmarkName.length());
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.xml.sax.ContentHandler#endElement(java.lang.String,
	 *      java.lang.String, java.lang.String)
	 */
	public void endElement(String uri, String localName, String qName)
			throws SAXException {
		if (qName.equals(ELEMENT_DESCRIPTION)) {
			descActive = false;
		}
	}

	
	public InputSource resolveEntity(String publicId, String systemId) throws SAXException {
		return resolver.resolveEntity(publicId, systemId);
	}

	public String getBenchmarkName() {
		return (this.benchmarkName.toString());
	}

	public String getBenchmarkVersion() {
		// version is an attribute - trim possible spaces
		return (this.benchmarkVersion.toString().trim());
	}

	public String getBenchmarkDescription() {
		// description is a text-node - trim possible spaces
		return (this.benchmarkDescription.toString().trim());
	}

	public void unparsedEntityDecl(String name, String publicId, String systemId, String notationName) throws SAXException {
		System.out.println("Entity: " + name);
	}

	public void skippedEntity(String name) throws SAXException {
		System.out.println("Skipped Entity: " + name);
	}
	
	
	
	
}
