/*
 *  BEEN: Benchmarking Environment
 *  ==============================
 *
 *  File author: Michal Tomcanyi
 *
 *  GNU Lesser General Public License Version 2.1
 *  ---------------------------------------------
 *  Copyright (C) 2004-2006 Distributed Systems Research Group,
 *  Faculty of Mathematics and Physics, Charles University in Prague
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License version 2.1, as published by the Free Software Foundation.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 *  MA  02111-1307  USA
 */
package cz.cuni.mff.been.benchmarkmanager;

/**
 * Status of an entity. Used on all levels of hierarchy.
 * 
 * @author Michal Tomcanyi
 */
public enum EntityStatus {
	/** Entity is configured but is waiting for generator to be started */
	CONFIGURED,
	/** Entity is ready to run, but was not yet submitted to task manager */
	DISPATCHED,
	/** Entity was submitted to the task manager. */
	SUBMITTED, 
	/** Entity is running. */
	RUNNING,
	/** Entity has finished/aborted. */
	FINISHED;

	/** String representation of the statuses. */
	private static final String[] STRINGS = {
		"configured",
		"dispatched",
		"submitted",
		"running",
		"finished"
	};
	
	/**
	 * Returns a string representation of the object.
	 * 
	 * @return a string representation of the object
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString() {
		return STRINGS[ordinal()];
	}	
	
}
