/*
 *  BEEN: Benchmarking Environment
 *  ==============================
 *
 *  File author: Michal Tomcanyi
 *
 *  GNU Lesser General Public License Version 2.1
 *  ---------------------------------------------
 *  Copyright (C) 2004-2006 Distributed Systems Research Group,
 *  Faculty of Mathematics and Physics, Charles University in Prague
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License version 2.1, as published by the Free Software Foundation.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 *  MA  02111-1307  USA
 */
package cz.cuni.mff.been.benchmarkmanager;

import java.rmi.RemoteException;

import cz.cuni.mff.been.common.BeenUtils;
import cz.cuni.mff.been.common.id.EID;
import cz.cuni.mff.been.taskmanager.TaskDescriptor;

public class ExperimentAdapter extends EntityAdapter<EID> 
	implements ExperimentEntityInterface {

	private final transient AnalysisMetadata analysis;
	
	ExperimentAdapter(AnalysisMetadata analysis) throws RemoteException {
		super(null);
		this.analysis = analysis;
	}
	
	/* (non-Javadoc)
	 * @see cz.cuni.mff.been.benchmarkmanager.ExperimentAdapterInterface#getEntity(cz.cuni.mff.been.common.id.EID)
	 */
	public ExperimentEntity getEntity(EID id) 
	throws RemoteException {
		return new ExperimentEntity(findExperiment(id));
	}

	/* (non-Javadoc)
	 * @see cz.cuni.mff.been.benchmarkmanager.ExperimentAdapterInterface#getEntities()
	 */
	public ExperimentEntity[] getEntities() throws RemoteException {
		ExperimentMetadata[] experiments = analysis.getExperiments();
		ExperimentEntity[] result = new ExperimentEntity[experiments.length];
		int i=0;
		for (ExperimentMetadata experiment : experiments) {
			result[i++] = new ExperimentEntity(experiment);
		}
		return result;
	}

	/* (non-Javadoc)
	 * @see cz.cuni.mff.been.benchmarkmanager.ExperimentAdapterInterface#getSubentityInterface(cz.cuni.mff.been.common.id.EID)
	 */
	public BinaryAdapter getSubentityInterface(EID id) throws RemoteException {
		return new BinaryAdapter(findExperiment(id));
	}

	public void deleteEntity(EID id) throws RemoteException {
		// TODO Auto-generated method stub
		
	}

	/* (non-Javadoc)
	 * @see cz.cuni.mff.been.benchmarkmanager.ExperimentAdapterInterface#getContext(cz.cuni.mff.been.common.id.EID)
	 */
	public String getContext(EID id) throws RemoteException {
		return findExperiment(id).getContextID();
	}

	/*
	 * Cannot delegate to parent, as its experiment is set to null
	 */
	public TaskDescriptor[] getTasks(EID id) throws RemoteException {
		return BeenUtils.sortTasks(findExperiment(id).getTasks());
	}
	
	/*
	 * Cannot delegate to parent, as its experiment is set to null
	 */
	public TaskDescriptor[] getAllTasks(EID id) throws RemoteException {
		return BeenUtils.sortTasks(findExperiment(id).getAllTasks());
	}
	

	private ExperimentMetadata findExperiment(EID id) {
		ExperimentMetadata exp = analysis.getExperiment(id);
		if (exp == null) {
			throw new IllegalArgumentException("Experiment EID(" + 
					id + ") does not exist");
		}
		return exp;
	}

}
