package cz.cuni.mff.been.benchmarkmanager;

import java.util.Arrays;
import java.util.LinkedList;

import cz.cuni.mff.been.benchmarkmanager.gui.SchedulerInfo;
import cz.cuni.mff.been.benchmarkmanager.plugins.VersionProvider;
import cz.cuni.mff.been.common.Version;
import cz.cuni.mff.been.common.id.AID;

/**
 * Class represents regression analysis metadata.
 * The difference from the comparison analysis is existence of a model experiment
 * and a scheduled version provider which c
 * @author mtomcany
 *
 */
public class RegressionAnalysisMetadata extends AnalysisMetadata {

	/**
	 * Model experiment from which regression experiments are derived
	 */
	private ExperimentMetadata modelExperiment;
	
	/**
	 * Schedule for version provider runs
	 */
	private SchedulerInfo schedule;
	
	/**
	 * List of versions already provided by the version provider
	 */
	private LinkedList<Version> processedVersions  = new LinkedList<Version>();
	
	/**
	 * Timestamp of version provider's last run
	 */
	private long lastRunDate = VersionProvider.FIRST_RUN;
	
	/**
	 * Timestamp of version provider's next run
	 */
	private long nextRunDate = VersionProvider.FIRST_RUN;

	public RegressionAnalysisMetadata(AID id) {
		super(id);
	}
	
	/**
	 * Sets the model experiment for the analysis
	 * @param modelExperiment
	 */
	public void setModelExperiment(ExperimentMetadata modelExperiment) {
		this.modelExperiment = modelExperiment;
	}
	
	public ExperimentMetadata getModelExperiment() {
		return modelExperiment;
	}
	
	public void setLastRunDate(long lastRunDate) {
		this.lastRunDate = lastRunDate;
	}
	
	public void setNextRunDate(long nextRunDate) {
		this.nextRunDate = nextRunDate;
	}
	
	public long getNextRunDate() {
		return nextRunDate;
	}
	
	public long getLastRunDate() {
		return lastRunDate;
	}

	public Version[] getProcessedVersions() {
		return processedVersions.toArray(new Version[processedVersions.size()]);
	}
	
	public void addProcessedVersions(Version[] versions) {
		this.processedVersions.addAll(Arrays.asList(versions));
	}
	
	@Override
	public boolean isRegression() {
		return true;
	}

	public void setSchedule(SchedulerInfo schedule) {
		this.schedule = schedule;
	}
	
	public SchedulerInfo getSchedule() {
		return schedule;
	}

	public long getHistoricalStart() {
		return schedule.getHistoricalStartDate();
	}
	
	public long getHistoricalEnd() {
		return schedule.getHistoricalEndDate();
	}
	
	
}
