/*
 *  BEEN: Benchmarking Environment
 *  ==============================
 *
 *  File author: Jaroslav Urban
 *
 *  GNU Lesser General Public License Version 2.1
 *  ---------------------------------------------
 *  Copyright (C) 2004-2006 Distributed Systems Research Group,
 *  Faculty of Mathematics and Physics, Charles University in Prague
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License version 2.1, as published by the Free Software Foundation.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 *  MA  02111-1307  USA
 */
package cz.cuni.mff.been.benchmarkmanager.plugins;

import cz.cuni.mff.been.benchmarkmanager.ExperimentMetadata;
import cz.cuni.mff.been.benchmarkmanager.gui.IllegalScreenSequenceException;
import cz.cuni.mff.been.benchmarkmanager.gui.Screen;
import cz.cuni.mff.been.resultsrepository.gui.CallbackRScripts;

/**
 * Creates the user interface used to configure benchmark experiments.
 * 
 * @author Michal Tomcanyi
 */
public abstract class Configurator {
	/** Benchmark experiment that is configured by this configurator */
	private ExperimentMetadata benchmarkExperiment;
	
	/** Flag indicating whether the configurator is running for regression model experiment */
	private boolean isRegression;
	
	
	/**
	 * @return the benchmark experiment
	 */
	public ExperimentMetadata getBenchmarkExperiment() {
		return benchmarkExperiment;
	}

	

	/**
	 * @param benchmarkExperiment the benchmark experiment
	 */
	public void setBenchmarkExperiment(ExperimentMetadata benchmarkExperiment) {
		this.benchmarkExperiment = benchmarkExperiment;
	}

	/**
	 * Sets regression flag
	 * @param isRegression
	 */
	public void setRegression(boolean isRegression) {
		this.isRegression = isRegression;
	}
	
	/**
	 * @return <code>true</code> when configurator is running for regression model experiment
	 */
	public boolean isRegression() {
		return isRegression;
	}
	

	/**
	 * @return the first screen.
	 * @throws ConfiguratorException if some error occured during creating this screen.
	 */
	public abstract Screen getFirstScreen() throws ConfiguratorException;

	/**
	 * 
	 * @param processedScreen previous screen
	 * @return the next screen or <code>null</code>if no more screens should follow
	 * @throws IllegalScreenSequenceException
	 * @throws ConfiguratorException if some error occured during creating this screen.
	 */
	public abstract Screen getNextScreen(Screen processedScreen) 
	throws IllegalScreenSequenceException, ConfiguratorException;

	/**
	 * @param processedScreen previous screen
	 * @return the next screen
	 * @throws IllegalScreenSequenceException
	 * @throws ConfiguratorException if some error occured during creating this screen.
	 */
	public abstract Screen getPreviousScreen(Screen processedScreen) 
	throws IllegalScreenSequenceException, ConfiguratorException;
	
	/**
	 * @return default values for R scripts invoked on analysis
	 */
	public abstract CallbackRScripts getDefaultRScripts();
}