/*
 *  BEEN: Benchmarking Environment
 *  ==============================
 *
 *  File author: Michal Tomcanyi
 *
 *  GNU Lesser General Public License Version 2.1
 *  ---------------------------------------------
 *  Copyright (C) 2004-2006 Distributed Systems Research Group,
 *  Faculty of Mathematics and Physics, Charles University in Prague
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License version 2.1, as published by the Free Software Foundation.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 *  MA  02111-1307  USA
 */
package cz.cuni.mff.been.benchmarkmanager.plugins;

import java.io.File;
import java.io.IOException;
import java.net.MalformedURLException;

import org.xml.sax.EntityResolver;
import org.xml.sax.InputSource;
import org.xml.sax.SAXException;


public class PluginEntityResolver implements EntityResolver {

	private static final String PLUGIN_DTD = "been-plugin.dtd";
	private static final String SYMBOLIC_NAMES_DTD = "symbolic-names.dtd";
	
	private String baseURI;
	
	public PluginEntityResolver(String baseURI) {
		this.baseURI = baseURI;
	}
	
	public InputSource resolveEntity(String publicId, String systemId) throws SAXException {
		try {
			// we obtain systemIDs in format baseURI/relativeSystemId
			
//			System.err.println("Resolver: " + systemId);
			InputSource resolved = null;
			if (systemId.endsWith(PLUGIN_DTD)) {
				resolved = new InputSource(new File(baseURI, PLUGIN_DTD).toURL().openStream());
			} else 
			if (systemId.endsWith(SYMBOLIC_NAMES_DTD)) {
				resolved = new InputSource(new File(baseURI, SYMBOLIC_NAMES_DTD).toURL().openStream());
			} else { 
				throw new SAXException("Unable to resolve: " + systemId);
			}
			resolved.setSystemId(baseURI);
			return resolved;
		} catch (MalformedURLException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		} catch (IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		return null;
	}
	
}
