/*
 * Created on Nov 7, 2006
 *
 * BEEN
 * @author Jaroslav Urban
 */
package cz.cuni.mff.been.benchmarkmanager.plugins.simpletest;

import java.net.InetAddress;

import cz.cuni.mff.been.benchmarkmanager.ExperimentMetadata;
import cz.cuni.mff.been.benchmarkmanager.gui.IllegalScreenSequenceException;
import cz.cuni.mff.been.benchmarkmanager.gui.Input;
import cz.cuni.mff.been.benchmarkmanager.gui.Item;
import cz.cuni.mff.been.benchmarkmanager.gui.Option;
import cz.cuni.mff.been.benchmarkmanager.gui.RSLInput;
import cz.cuni.mff.been.benchmarkmanager.gui.Screen;
import cz.cuni.mff.been.benchmarkmanager.gui.Section;
import cz.cuni.mff.been.benchmarkmanager.gui.Select;
import cz.cuni.mff.been.benchmarkmanager.plugins.Configurator;
import cz.cuni.mff.been.benchmarkmanager.plugins.ConfiguratorException;
import cz.cuni.mff.been.common.IntegerInputValidator;
import cz.cuni.mff.been.common.id.SID;
import cz.cuni.mff.been.common.rsl.Condition;
import cz.cuni.mff.been.common.rsl.EqualsCondition;
import cz.cuni.mff.been.common.rsl.ParseException;
import cz.cuni.mff.been.common.rsl.ParserWrapper;
import cz.cuni.mff.been.resultsrepository.gui.CallbackRScripts;

/**
 * Configurator for a simple benchmark plugin test.
 * 
 * @author Jaroslav Urban
 */
public class SimpleTestConfigurator extends Configurator {

	private enum ScreenID {
		/** Screen for setting properties of the test. */
		TEST_PROPERTIES,
		/** Screen for setting restrictions for the Test role. */
		TEST_ROLE,
	}
	
	/** 
	 * Last processed screen, it's used for preventing the user 
	 * from jumping more than 1 screen forward with the help of the 
	 * browser history.
	 */
	private int lastScreen = -1;

	private static final int DEFAULT_WAIT_TIME = 5;
	private static final int DEFAULT_HOST_COUNT = 1;
	private static final int DEFAULT_RUN_COUNT = 0;
	private static final int DEFAULT_BINARY_COUNT = 0;
	
	private Condition rslTestRole;
	private int waitTime;
	private int hostCount;
	private int runCount;
	private int binaryCount;
	private String exclusivity;


	/* (non-Javadoc)
	 * @see cz.cuni.mff.been.benchmarkmanager.plugins.Configurator#getFirstScreen()
	 */
	@Override
	public Screen getFirstScreen() throws ConfiguratorException {
		return createRoleScreen(ScreenID.TEST_ROLE, 
				SimpleTestGenerator.TEST_ROLE);
	}
	
	/* (non-Javadoc)
	 * @see cz.cuni.mff.been.benchmarkmanager.plugins.Configurator#getNextScreen(cz.cuni.mff.been.benchmarkmanager.gui.Screen)
	 */
	@Override
	public Screen getNextScreen(Screen processedScreen)
			throws IllegalScreenSequenceException, ConfiguratorException {
		// get the values eneter by user in the previous screen
		getUserInput(processedScreen);
		// get the Screen ID of the previous screen
		int id = ((Long) processedScreen.getSid().value()).intValue();
		
		// check if user didn't go forward more than 1 screen
		if (!(id <= lastScreen)) {
			throw new IllegalScreenSequenceException(
					"You jumped more than 1 screen forward");
		}
		ScreenID screenID = ScreenID.values()[id];
		
		// determine which screen is next
		switch(screenID) {
			case TEST_ROLE :
				return createTestPropertiesScreen();
			case TEST_PROPERTIES :
				createExperiment();
				return null;
			default :
				throw new ConfiguratorException("Illegal screen: " + processedScreen.getSid());
		}
	}
	
	@Override
	public CallbackRScripts getDefaultRScripts() {
		if (isRegression()) {
			return new CallbackRScripts("","","","","");
		} else {
			return new CallbackRScripts("","","","","");
		}
	}


	/* (non-Javadoc)
	 * @see cz.cuni.mff.been.benchmarkmanager.plugins.Configurator#getPreviousScreen(cz.cuni.mff.been.benchmarkmanager.gui.Screen)
	 */
	@Override
	public Screen getPreviousScreen(Screen processedScreen)
			throws IllegalScreenSequenceException, ConfiguratorException {
		int id = ((Long) processedScreen.getSid().value()).intValue();
		ScreenID screenID = ScreenID.values()[id];
		
		switch(screenID) {
			case TEST_ROLE :
				return null;
			case TEST_PROPERTIES :
				return createRoleScreen(ScreenID.TEST_ROLE, 
						SimpleTestGenerator.TEST_ROLE);
			default :
				throw new ConfiguratorException("Illegal screen: " + processedScreen.getSid());
		}
	}

	private Screen createTestPropertiesScreen() {
		lastScreen = ScreenID.TEST_PROPERTIES.ordinal();
		
		IntegerInputValidator intValidator = new IntegerInputValidator();
		
		Input waitTimeInput = new Input("Wait time",
				String.valueOf(DEFAULT_WAIT_TIME),
				Input.Size.SMALL,
				intValidator);

		Input hostCountInput = new Input("Host count",
				String.valueOf(DEFAULT_HOST_COUNT),
				Input.Size.SMALL,
				intValidator);

		Option[] exclusivityOptions = new Option[] {
				new Option(SimpleTestGenerator.Exclusivity.NONE.toString(),
						SimpleTestGenerator.Exclusivity.NONE.toString()),
				new Option(SimpleTestGenerator.Exclusivity.CONTEXT_EXCLUSIVE.toString(),
						SimpleTestGenerator.Exclusivity.CONTEXT_EXCLUSIVE.toString()),
				new Option(SimpleTestGenerator.Exclusivity.EXCLUSIVE.toString(),
						SimpleTestGenerator.Exclusivity.EXCLUSIVE.toString())
			};
		Select exclusivitySelect = new Select("Exclusivity", 
				exclusivityOptions, 0);

		Input binaryCountInput = new Input("Binaries",
				String.valueOf(DEFAULT_BINARY_COUNT),
				Input.Size.SMALL,
				intValidator);

		Input runCountInput = new Input("Runs",
				String.valueOf(DEFAULT_RUN_COUNT),
				Input.Size.SMALL,
				intValidator);

		Section section = new Section(
				new Item[] {
						waitTimeInput, 
						hostCountInput, 
						exclusivitySelect,
						binaryCountInput,
						runCountInput},
				"Test properties",
				"Configure parameters of this test");

		return new Screen(new SID(ScreenID.TEST_PROPERTIES.ordinal()), 
				new Section[] {section});
	}

	/**
	 * Creates a screen for configuring a benchmarking role.
	 * 
	 * @param sid ScreenID of the screen that will be created
	 * @param roleName name of the role
	 * @return screen for configuring a benchmarking role.
	 */
	private Screen createRoleScreen(ScreenID sid, String roleName) {
		lastScreen = sid.ordinal();
		
		Condition condition = null;
		try {
			condition = new EqualsCondition<String>("name", InetAddress.getLocalHost().getCanonicalHostName());
		} catch (Exception e) {
			condition = new EqualsCondition<String>("name", "some.cool.host.com");
		}
		
		RSLInput rsl = new RSLInput("Host restrictions", condition.toString());

		Section section = new Section(new Item[] {rsl}, 
				roleName + " role", 
				null);
		return new Screen(new SID(sid.ordinal()), new Section[] {section});
	}

	/**
	 * Get the values enter by user in a screen.
	 * 
	 * @param screen
	 * @throws IllegalScreenSequenceException
	 */
	private void getUserInput(Screen screen) throws ConfiguratorException {
		int id = ((Long) screen.getSid().value()).intValue();
		ScreenID screenID = ScreenID.values()[id];
		switch (screenID) {
			case TEST_PROPERTIES :
				processTestPropertiesScreen(screen);
				break;
			case TEST_ROLE :
				rslTestRole = processRoleScreen(screen);
				break;
			default :
				throw new ConfiguratorException("Illegal screen: " + screen.getSid());
		}
	}

	/**
	 * Gets the values entered by the user in a benchmarking role screen.
	 * 
	 * @param screen
	 * @return RSL condition on host
	 */
	private Condition processRoleScreen(Screen screen) {
		Section[] sections = screen.getSections();
		RSLInput rsl = (RSLInput) sections[0].getItems()[0];
		try {
			return ParserWrapper.parseString(rsl.getValue());
		} catch (ParseException e) {
			// we never get exception here, because RSLInput is validating
			assert false: "RSL from RSLInput is invalid";
			return null;
		}
	}

	/**
	 * Gets the values entered by the user in the properties screen.
	 * 
	 * @param screen
	 */
	private void processTestPropertiesScreen(Screen screen) {
		Section section = screen.getSections()[0];
		Input input = (Input) section.getItems()[0];
		waitTime = Integer.valueOf(input.getValue());
		input = (Input) section.getItems()[1];
		hostCount = Integer.valueOf(input.getValue());
		Select exclusivitySelect = (Select) section.getItems()[2];
		exclusivity = exclusivitySelect.getSelectedId();
		input = (Input) section.getItems()[3];
		binaryCount = Integer.valueOf(input.getValue());
		input = (Input) section.getItems()[4];
		runCount = Integer.valueOf(input.getValue());
	}

	/**
	 * Sets the user given values in the configured experiment.
	 *
	 */
	private void createExperiment() throws ConfiguratorException {
		ExperimentMetadata experiment = getBenchmarkExperiment();
		experiment.setBinaryCount(binaryCount);
		experiment.setRunCount(runCount);
		
		// set hostname properties
		experiment.addBenchmarkingRole(SimpleTestGenerator.TEST_ROLE, 
				rslTestRole, hostCount);

		// properties
		experiment.setProperty(SimpleTestGenerator.WAIT_TIME, 
				String.valueOf(waitTime));
		experiment.setProperty(SimpleTestGenerator.EXCLUSIVITY, 
				exclusivity);

		System.out.println("Wait time: " + waitTime);
		System.out.println("Test role: " + rslTestRole);
		System.out.println("Exclusivity: " + exclusivity);
	}

}
