/*
 *  BEEN: Benchmarking Environment
 *  ==============================
 *
 *  File author: Michal Tomcanyi
 *
 *  GNU Lesser General Public License Version 2.1
 *  ---------------------------------------------
 *  Copyright (C) 2004-2006 Distributed Systems Research Group,
 *  Faculty of Mathematics and Physics, Charles University in Prague
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License version 2.1, as published by the Free Software Foundation.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 *  MA  02111-1307  USA
 */
package cz.cuni.mff.been.benchmarkmanager.plugins.xampler;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;

import cz.cuni.mff.been.benchmarkmanager.gui.IllegalScreenSequenceException;
import cz.cuni.mff.been.benchmarkmanager.gui.Input;
import cz.cuni.mff.been.benchmarkmanager.gui.Item;
import cz.cuni.mff.been.benchmarkmanager.gui.Option;
import cz.cuni.mff.been.benchmarkmanager.gui.RSLInput;
import cz.cuni.mff.been.benchmarkmanager.gui.RadioWithSectionItem;
import cz.cuni.mff.been.benchmarkmanager.gui.RadiosWithSections;
import cz.cuni.mff.been.benchmarkmanager.gui.Screen;
import cz.cuni.mff.been.benchmarkmanager.gui.Section;
import cz.cuni.mff.been.benchmarkmanager.gui.Select;
import cz.cuni.mff.been.benchmarkmanager.gui.Input.Size;
import cz.cuni.mff.been.benchmarkmanager.plugins.Configurator;
import cz.cuni.mff.been.common.IntegerInputValidator;
import cz.cuni.mff.been.common.IntegerIntervalInputValidator;
import cz.cuni.mff.been.common.NotEmptyInputValidator;
import cz.cuni.mff.been.common.id.SID;
import cz.cuni.mff.been.common.rsl.Condition;
import cz.cuni.mff.been.common.rsl.EqualsCondition;
import cz.cuni.mff.been.common.rsl.ParseException;
import cz.cuni.mff.been.common.rsl.ParserWrapper;
import cz.cuni.mff.been.resultsrepository.gui.CallbackRScripts;

public class XamplerConfigurator extends Configurator {
	
	private enum ScreenID {
			NONE,
			CVS_REPOSITORY,
			SW_SELECTION,
			TEST_CONSTANTS,
			SUITE_SELECTION,
			SUITE_SUBSELECTION,
			CLIENT_ROLE,
			SERVER_ROLE,
			COMPILE_ROLE,
			FINISH;
			
			public SID getSID() {
				return new SID(ordinal());
			}
			
	}
	
	public enum XamplerSuite {
		Concurrency_Client_Connections(
				"Concurrency_Client_Connections",
				null,
				new String[]{"Number of clients"}
		),
		Dispatch_Servant_Instances(
				"Dispatch_Servant_Instances",
				null,
				new String[]{
						"Instances min",
						"Instances max",
						"Instances limit",
						"Instances scale",
						"Threads min",
						"Threads max",
						"Threads limit",
						"Threads scale"
				}
		),
		Dispatch_Servant_Lifecycle("Dispatch_Servant_Lifecycle",
				null,
				new String[] {
				"Instances min",
				"Instances max",
				"Instances limit",
				"Instances scale"
				}
		),
		Invocation_Dynamic(
				"Invocation_Dynamic",
				null,
				new String[] {
				"Threads min",
				"Threads max",
				"Threads limit",
				"Threads scale"
				}
		),
		Invocation_Initial(
				"Invocation_Initial",
				null,
				null
		),
		Invocation_Static(
				"Invocation_Static",
				null,
				new String[] {
				"Threads min",
				"Threads max",
				"Threads limit",
				"Threads scale"
				}
				),
		Ping(
				"Ping",
				null,
				null),
		Void(
				"Void",
				null,
				new String[] {
				"Threads min",
				"Threads max",
				"Threads limit",
				"Threads scale"
				}
		),
		
		// ------ WITH SUBMENU -------
		Marshal_Types_Array("Marshal_Types_Array",
				new String[] {
				"Boolean_1024_IN",
				"Boolean_1024_INOUT",
				"Boolean_1024_OUT",
				"Boolean_1024_RETURN",
				"Char_1024_IN",
				"Char_1024_INOUT",
				"Char_1024_OUT",
				"Char_1024_RETURN",
				"Double_1024_IN",
				"Double_1024_INOUT",
				"Double_1024_OUT",
				"Double_1024_RETURN",
				"Double_128_IN",
				"Double_128_INOUT",
				"Double_128_OUT",
				"Double_128_RETURN",
				"Float_1024_IN",
				"Float_1024_INOUT",
				"Float_1024_OUT",
				"Float_1024_RETURN",
				"Float_256_IN",
				"Float_256_INOUT",
				"Float_256_OUT",
				"Float_256_RETURN",
				"LongDouble_1024_IN",
				"LongDouble_1024_INOUT",
				"LongDouble_1024_OUT",
				"LongDouble_1024_RETURN",
				"LongDouble_64_IN",
				"LongDouble_64_INOUT",
				"LongDouble_64_OUT",
				"LongDouble_64_RETURN",
				"LongLong_1024_IN",
				"LongLong_1024_INOUT",
				"LongLong_1024_OUT",
				"LongLong_1024_RETURN",
				"LongLong_128_IN",
				"LongLong_128_INOUT",
				"LongLong_128_OUT",
				"LongLong_128_RETURN",
				"Long_1024_IN",
				"Long_1024_INOUT",
				"Long_1024_OUT",
				"Long_1024_RETURN",
				"Long_256_IN",
				"Long_256_INOUT",
				"Long_256_OUT",
				"Long_256_RETURN",
				"Octet_1024_IN",
				"Octet_1024_INOUT",
				"Octet_1024_OUT",
				"Octet_1024_RETURN",
				"Short_1024_IN",
				"Short_1024_INOUT",
				"Short_1024_OUT",
				"Short_1024_RETURN",
				"Short_512_IN",
				"Short_512_INOUT",
				"Short_512_OUT",
				"Short_512_RETURN",
				"ULongLong_1024_IN",
				"ULongLong_1024_INOUT",
				"ULongLong_1024_OUT",
				"ULongLong_1024_RETURN",
				"ULongLong_128_IN",
				"ULongLong_128_INOUT",
				"ULongLong_128_OUT",
				"ULongLong_128_RETURN",
				"ULong_1024_IN",
				"ULong_1024_INOUT",
				"ULong_1024_OUT",
				"ULong_1024_RETURN",
				"ULong_256_IN",
				"ULong_256_INOUT",
				"ULong_256_OUT",
				"ULong_256_RETURN",
				"UShort_1024_IN",
				"UShort_1024_INOUT",
				"UShort_1024_OUT",
				"UShort_1024_RETURN",
				"UShort_512_IN",
				"UShort_512_INOUT",
				"UShort_512_OUT",
				"UShort_512_RETURN",
				"WChar_1024_IN",
				"WChar_1024_INOUT",
				"WChar_1024_OUT",
				"WChar_1024_RETURN",
				"WChar_512_IN",
				"WChar_512_INOUT",
				"WChar_512_OUT",
				"WChar_512_RETURN"},
				new String[] {
				"Threads min",
				"Threads max",
				"Threads limit",
				"Threads scale"
				}),
		Marshal_Types_Single("Marshal_Types_Single",
				new String[]{
				"Boolean_IN",
				"Boolean_INOUT",
				"Boolean_OUT",
				"Boolean_RETURN",
				"Char_IN",
				"Char_INOUT",
				"Char_OUT",
				"Char_RETURN",
				"Double_IN",
				"Double_INOUT",
				"Double_OUT",
				"Double_RETURN",
				"Float_IN",
				"Float_INOUT",
				"Float_OUT",
				"Float_RETURN",
				"LongDouble_IN",
				"LongDouble_INOUT",
				"LongDouble_OUT",
				"LongDouble_RETURN",
				"LongLong_IN",
				"LongLong_INOUT",
				"LongLong_OUT",
				"LongLong_RETURN",
				"Long_IN",
				"Long_INOUT",
				"Long_OUT",
				"Long_RETURN",
				"Octet_IN",
				"Octet_INOUT",
				"Octet_OUT",
				"Octet_RETURN",
				"Short_IN",
				"Short_INOUT",
				"Short_OUT",
				"Short_RETURN",
				"ULongLong_IN",
				"ULongLong_INOUT",
				"ULongLong_OUT",
				"ULongLong_RETURN",
				"ULong_IN",
				"ULong_INOUT",
				"ULong_OUT",
				"ULong_RETURN",
				"UShort_IN",
				"UShort_INOUT",
				"UShort_OUT",
				"UShort_RETURN",
				"WChar_IN",
				"WChar_INOUT",
				"WChar_OUT",
				"WChar_RETURN"},
				new String[] {
				"Threads min",
				"Threads max",
				"Threads limit",
				"Threads scale"
				}),
		Marshal_Octet_Sequence("Marshal_Octet_Sequence",
				new String[]{"IN", "INOUT", "OUT", "RETURN" },
				new String[] {
						"Octets min",
						"Octets max",
						"Octets limit",
						"Octets scale",
						"Threads min",
						"Threads max",
						"Threads limit",
						"Threads scale"
						}
		),
		Marshal_Delayed_Sequence("Marshal_Delayed_Sequence",
				new String[]{"Accessed", "Ignored"},
				new String[] {
				"Threads min",
				"Threads max",
				"Threads limit",
				"Threads scale"
				}),
		Marshal_Delayed_Any("Marshal_Delayed_Any",
				new String[]{"Accessed", "Ignored"},
				new String[] {
				"Threads min",
				"Threads max",
				"Threads limit",
				"Threads scale"
				});
		
		private static final String[][] commonConstants = new String[][] {
			new String[]{"SAM_TestSamples", "5"},
			new String[]{"SAM_MaxItems", "100000"},
			new String[]{"SAM_MaxOctets", "100000"},
			new String[]{"SAM_MaxThreads", "100"},
			new String[]{"SAM_MaxInstances", "100000"},
			new String[]{"MEA_WarmUpTimeMin", "5"},
			new String[]{"MEA_WarmUpTimeMax", "20"},
			new String[]{"MEA_RawCycles", "10000"},
			new String[]{"MEA_SoloCycles", "5000"},
			new String[]{"MEA_UsageCycles", "60"},
			new String[]{"MEA_SharedTime", "60"}
		};
		
		private static final HashMap<String, String> suiteDefaults = new HashMap<String, String>();
		
		static {
			suiteDefaults.put("Instances min", "1");
			suiteDefaults.put("Instances max", "100000");
			suiteDefaults.put("Instances limit", "5");
			suiteDefaults.put("Instances scale", "10");
			suiteDefaults.put("Threads min", "1");
			suiteDefaults.put("Threads max", "100");
			suiteDefaults.put("Threads limit", "5");
			suiteDefaults.put("Threads scale", "10");
			suiteDefaults.put("Octets min", "1");
			suiteDefaults.put("Octets max", "100000");
			suiteDefaults.put("Octets limit", "5");
			suiteDefaults.put("Octets scale", "10");
			suiteDefaults.put("Number of clients", "1");
		}
		
		
		
		private String name;
		private String[] subselections;
		private String[] execArgs;
		private static final HashMap<String, XamplerSuite> lookup = new HashMap<String, XamplerSuite>(); 
		
		XamplerSuite(String suiteName, String[] subSelections, String[] execArgs) {
			this.name = suiteName;
			this.subselections = subSelections;
			this.execArgs = execArgs;
		}

		public String getName() {
			return name;
		}
		
		public boolean hasSubMenu() {
			return subselections != null;
		}
		
		public String[] getSubMenu() {
			return subselections;
		}
		
		public boolean hasExecArgs() {
			return execArgs != null;
		}
		
		public String[] getExecArgs() {
			return execArgs;
		}
		
		public static XamplerSuite getByName(String suiteName) {
			if (lookup.size() == 0) {
				for (XamplerSuite suite : XamplerSuite.values()) {
					lookup.put(suite.getName(), suite);
				}
			}
			return lookup.get(suiteName);
		}
		
		public static String[][] getCommonConstants() {
			return commonConstants;
		}
		
		public static String getDefaultValue(String name) {
			return suiteDefaults.get(name);
		}
		
	}
	
	
	/**
	 * Constant for naviagtion direction PREVIOUS
	 */
	private static final int PREV = 0;
	/**
	 * Constant for naviagtion direction NEXT
	 */
	private static final int NEXT = 1;
	

	public Screen getFirstScreen() {
		return cvsRepositoryDialog();
	}

	@Override
	public CallbackRScripts getDefaultRScripts() {
		if (isRegression()) {
			return new CallbackRScripts("", 
					"xampler.generateRunsStatistics()\nxampler.generateBinaryStatistics()\nxampler.registerInvalidateScripts()\n", 
					"xampler.generateExperimentStatistics()\nxampler.generateExperimentGraph()\nxampler.generateRegressionAnalysisGraph()\n", 
					"", "");
		} else {
			return new CallbackRScripts("", 
					"xampler.generateRunsStatistics()\nxampler.generateBinaryStatistics()\nxampler.registerInvalidateScripts()\n", 
					"xampler.generateExperimentStatistics()\nxampler.generateExperimentGraph()\n", 
					"", "");
		}
	}	
	public Screen getNextScreen(Screen processedScreen) throws IllegalScreenSequenceException {
		int id = ((Long) processedScreen.getSid().value()).intValue();
		ScreenID currentID = ScreenID.values()[id];
		storeParameters(currentID, processedScreen);
		ScreenID nextID = getTransition(currentID, NEXT);
		return getScreen(nextID, processedScreen);
	}

	public Screen getPreviousScreen(Screen processedScreen) throws IllegalScreenSequenceException {
		int id = ((Long) processedScreen.getSid().value()).intValue();
		ScreenID currentID = ScreenID.values()[id];
		storeParameters(currentID, processedScreen);
		ScreenID nextID = getTransition(currentID, PREV);
		return getScreen(nextID, processedScreen);
	}

	private Screen cvsRepositoryDialog() {
		// CVS server location
		Item host = new Input("Host","omniorb.cvs.sourceforge.net", Size.BIG, new NotEmptyInputValidator());
		Item path = new Input("Repository path", "/cvsroot/omniorb", Size.BIG, new NotEmptyInputValidator());
		Section location = new Section(new Item[]{host,path},"Location", "CVS repository location.");

		// Authentication
		Item user = new Input("User","anonymous", Size.BIG, new NotEmptyInputValidator());
		Item pass= new Input("Password", "none", Size.BIG, null);
		Section authentication = new Section(new Item[]{user,pass},"Authentication", "CVS access account");
		
		// Branch
		Item branchItem =  new Input("Branch", "omni4_0_develop",Size.BIG,new NotEmptyInputValidator());
		Section branch = new Section(new Item[]{branchItem},"Development branch",
				"OmniORB development branch. See details at http://omniorb.sourceforge.net");
		
		return new Screen(ScreenID.CVS_REPOSITORY.getSID(),new Section[]{location,authentication,branch});
	}
	
	private Screen softwareSelection() {
		Item xamplerVersion = new Input("Xampler version", "1.11",
				Size.SMALL, new NotEmptyInputValidator());
		
		Item omniorbVersion = new Input("omniORB version", "4.0.5",
				Size.SMALL, new NotEmptyInputValidator());
		
		Item omniorbBranch = new Input("omniORB branch", "4.0",
				Size.SMALL, new NotEmptyInputValidator());
		
		Section swSelection = new Section(
				new Item[]{xamplerVersion,omniorbVersion, omniorbBranch},
				"Software selection",
				"Select software to perform measurements on.");
		
		Item runCount = new Input("Number of runs", "1", Size.SMALL,
				new IntegerIntervalInputValidator(1,Integer.MAX_VALUE));
		
		Item binariesCount = new Input("Software binaries", "1", Size.SMALL,
				new IntegerIntervalInputValidator(1,Integer.MAX_VALUE));
		
		Section runSection = new Section(
			new Item[]{runCount, binariesCount},
				"Runs and binaries",
				"Number of runs to perform and software binaries to create."
				);
		return new Screen(ScreenID.SW_SELECTION.getSID(),
				new Section[]{swSelection, runSection});
	}
	
	/**
	 * @param current Current screen ID
	 * @param direction direction of naviagation 
	 * @return id of screen that should follow
	 * @see #NEXT
	 * @see #PREV
	 */
	private ScreenID getTransition(ScreenID current, int direction) throws IllegalScreenSequenceException {
		
		// forward transitions 
		if (direction == NEXT) {
			switch (current) {
				case NONE:
					return ScreenID.NONE;
				case CVS_REPOSITORY:
					return ScreenID.SW_SELECTION;
				case SW_SELECTION:
					return ScreenID.SUITE_SELECTION;
				case SUITE_SELECTION:
					return doSubselection() ? ScreenID.SUITE_SUBSELECTION : ScreenID.TEST_CONSTANTS;
				case SUITE_SUBSELECTION:
					return ScreenID.TEST_CONSTANTS;
				case TEST_CONSTANTS:
					return ScreenID.CLIENT_ROLE;
				case CLIENT_ROLE:
					return ScreenID.SERVER_ROLE;
				case SERVER_ROLE:
					return ScreenID.COMPILE_ROLE;
				case COMPILE_ROLE:
					return ScreenID.FINISH;
				case FINISH:
					throw new IllegalScreenSequenceException("There is no following screen after current");
			}
		}
		
		// backward transitions
		if (direction == PREV) {
			switch (current) {
				case NONE:
					throw new IllegalScreenSequenceException("There is no previous screen before current");
				case CVS_REPOSITORY:
					return ScreenID.NONE;
				case SW_SELECTION:
					return ScreenID.CVS_REPOSITORY;
				case SUITE_SELECTION:
					return ScreenID.SW_SELECTION;
				case SUITE_SUBSELECTION:
					return ScreenID.SUITE_SELECTION;
				case TEST_CONSTANTS:
					return ScreenID.SUITE_SELECTION;
				case CLIENT_ROLE:
					return ScreenID.TEST_CONSTANTS;
				case SERVER_ROLE:
					return ScreenID.CLIENT_ROLE;
				case COMPILE_ROLE:
					return ScreenID.SERVER_ROLE;
				case FINISH:
					return ScreenID.COMPILE_ROLE;
			}
		}
		
		throw new IllegalArgumentException("Invalid navigation direction value");
	}
	
	private Screen getScreen(ScreenID id, Screen processedScreen) throws IllegalScreenSequenceException {
		switch (id) {
			case NONE:
					return null;
			case CVS_REPOSITORY:
					return cvsRepositoryDialog();
			case SW_SELECTION:
					return softwareSelection();
			case TEST_CONSTANTS:
					return testConstants();
			case SUITE_SELECTION:
					return suiteSelection();
			case SUITE_SUBSELECTION:
					return suiteSubSelection();
			case CLIENT_ROLE:
					return clientRole();
			case SERVER_ROLE:
					return serverRole();
			case COMPILE_ROLE:
					return serverCompile(processedScreen);
			case FINISH:
					return null;
			default:
					throw new IllegalScreenSequenceException("No screen defined for state: " + id);
		}
	}

	private Screen serverCompile(Screen processedScreen) {
		Screen screen = new Screen(ScreenID.COMPILE_ROLE.getSID(), createCompileScreen());
		return screen;
	}

	private Screen clientRole() {
		Condition condition = new EqualsCondition<String>("os.family","Linux");
		RSLInput rsl = new RSLInput("Host restrictions", condition.toString());

		Section section = new Section(
					new Item[]{rsl},
					"Client host specification", 
					"Specify restrictions for the role. Platform will be added to restrictions automatically."
					);
		
		return new Screen(ScreenID.CLIENT_ROLE.getSID(), new Section[]{section});
	}

	private Screen serverRole() {
		Condition condition = new EqualsCondition<String>("os.family","Linux");
		RSLInput rsl = new RSLInput("Host restrictions", condition.toString());
		
		Section section = new Section(
				new Item[]{rsl},
				"Server host specification", 
				"Specify restrictions for the role. Platform will be added to restrictions automatically."
				);
		
		return new Screen(ScreenID.SERVER_ROLE.getSID(),new Section[]{section});
	}
	
	private Section[] createCompileScreen() {
		Condition condition = new EqualsCondition<String>("os.family","Linux");
		RSLInput rsl = new RSLInput("Host restrictions", condition.toString());
		
		Section section = new Section(
				new Item[]{rsl},
				"Compilation host",
				"Host that will run checkouts and compilations."
				);
		return new Section[]{section};	
	}

	private Screen suiteSelection() {
		Option[] suites = new Option[XamplerSuite.values().length];
		suites[0] = new Option(XamplerSuite.Ping.getName(), XamplerSuite.Ping.getName());
		int i = 1;
		for (XamplerSuite suite : XamplerSuite.values()) {
			if (! XamplerSuite.Ping.getName().equals(suite.getName())) {	
				suites[i++] = new Option(suite.getName(), suite.getName());
			}
		}
		
		
		Select suitesSelect = new Select("Benchmarking suite", suites, 0);
		
		Screen s = new Screen(ScreenID.SUITE_SELECTION.getSID(),
				new Section[] { new Section(new Item[] { suitesSelect },
						"Xampler suite",
						"Select suite that will be used for the benchmark.") });
		return s;
	}
	
	private Screen suiteSubSelection() {
		String suiteName = getBenchmarkExperiment().getProperty("xampler.suite");
		
		XamplerSuite subMenuSuite = null;
		for (XamplerSuite candidate : XamplerSuite.values()) {
			if (candidate.getName().equalsIgnoreCase(suiteName)) {
				subMenuSuite = candidate;
				break;
			}
		}
		
		Option[] suites = new Option[subMenuSuite.getSubMenu().length];
		int i = 0;
		for (String menuEntry : subMenuSuite.getSubMenu()) {
				suites[i++] = new Option(menuEntry, menuEntry);
		}
		Select suitesSelect = new Select("Suite subtype", suites, 0);
		
		Screen s = new Screen(ScreenID.SUITE_SUBSELECTION.getSID(), new Section[] {
				new Section(new Item[]{suitesSelect},
						suiteName + " subtype",
						"Select subtype for " + suiteName)
				});
		return s;
	}

	private Screen testConstants() {
		
		List<Section> sections = new ArrayList<Section>();
		
		Input[] constantsInput = new Input[XamplerSuite.getCommonConstants().length];
		int i = 0;
		for (String[] item : XamplerSuite.getCommonConstants()) {
			constantsInput[i++] = new Input(item[0], item[1], Size.SMALL, new IntegerInputValidator()); 
		}
		
		Section commonSection = new Section(constantsInput,
				"General settings" ,
				"Common benchmark settings."
				);
		
		sections.add(commonSection);

		String suiteName = getBenchmarkExperiment().getProperty("xampler.suite");
		
		XamplerSuite suite  = XamplerSuite.getByName(suiteName);
		if (suite.hasExecArgs()) {
			
			constantsInput = new Input[suite.getExecArgs().length];
			i = 0;
			for (String arg : suite.getExecArgs()) {
				constantsInput[i++] = new Input(arg, XamplerSuite.getDefaultValue(arg), Size.SMALL, new IntegerInputValidator());
			}
		
			Section runtimeSection = new Section(constantsInput,  null, null);

			RadioWithSectionItem[] radioItems = new RadioWithSectionItem[]{
					new RadioWithSectionItem(new Option("no", "No"), null),
					new RadioWithSectionItem(new Option("yes", "Yes"), runtimeSection)
			};
			
			int selectIndex = 0;
			if (XamplerSuite.Concurrency_Client_Connections.getName().equals(getBenchmarkExperiment().getProperty("xampler.suite"))) {
				selectIndex = 1;
			}
			Item radiosSection = new RadiosWithSections(radioItems, selectIndex);
			
			sections.add(
					new Section(new Item[]{radiosSection}, "Runtime settings",
					"Override compiled setttings in runtime?")
			);
			
		}
		
		return new Screen(ScreenID.TEST_CONSTANTS.getSID(),
				(Section[]) sections.toArray(new Section[sections.size()]));
	
	}
	
	private boolean doSubselection() {
		String suiteName = getBenchmarkExperiment().getProperty("xampler.suite");
		
		for (XamplerSuite candidate : XamplerSuite.values()) {
			if (candidate.getName().equalsIgnoreCase(suiteName)) {
				return candidate.hasSubMenu();
			}
		}
		
		return false;
	}
	
	private void storeParameters(ScreenID processedID, Screen processed) {
		RSLInput hostRSL = null;
		switch (processedID) {
			case CVS_REPOSITORY:
				StringBuilder repository = new StringBuilder(":pserver:");
				// user
				repository.append(((Input)processed.getSections()[1].getItems()[0]).getValue());
				repository.append("@");
				// host
				repository.append(((Input)processed.getSections()[0].getItems()[0]).getValue());
				repository.append(":");
				// path
				repository.append(((Input)processed.getSections()[0].getItems()[1]).getValue());
				
				String password = ((Input)processed.getSections()[1].getItems()[1]).getValue();
				String branch = ((Input)processed.getSections()[2].getItems()[0]).getValue();
				
				getBenchmarkExperiment().setProperty("cvs.repository",repository.toString());
				getBenchmarkExperiment().setProperty("cvs.password",password);
				getBenchmarkExperiment().setProperty("cvs.branch",branch);
				break;
			case SW_SELECTION:
				Input xamplerVersion = (Input) processed.getSections()[0].getItems()[0];
				Input softwareVersion = (Input) processed.getSections()[0].getItems()[1];
				Input omniorbBranch= (Input) processed.getSections()[0].getItems()[2];
				getBenchmarkExperiment().setProperty("xampler.version", xamplerVersion.getValue());
				getBenchmarkExperiment().setProperty("software.version", softwareVersion.getValue());
				getBenchmarkExperiment().setProperty("software.branch", omniorbBranch.getValue());
				
				Input runCount = (Input) processed.getSections()[1].getItems()[0];
				Input binCount = (Input) processed.getSections()[1].getItems()[1];
				
				getBenchmarkExperiment().setRunCount(Integer.parseInt(runCount.getValue().trim()));
				getBenchmarkExperiment().setBinaryCount(Integer.parseInt(binCount.getValue().trim()));
				break;
			case SUITE_SELECTION:
				Select suite = (Select) processed.getSections()[0].getItems()[0];
				getBenchmarkExperiment().setProperty("xampler.suite", suite.getSelectedId());
				break;
			case TEST_CONSTANTS:
				for (Item item : processed.getSections()[0].getItems()) {
					Input input = (Input) item;
					getBenchmarkExperiment().setProperty(input.getLabel(), input.getValue());
				}
				
				// set number of samples
				int samTestSamples = Integer.parseInt(
						getBenchmarkExperiment().getProperty("SAM_TestSamples", XamplerSuite.getCommonConstants()[0][1]).trim());
				int meaRawCycles = Integer.parseInt(
						getBenchmarkExperiment().getProperty("MEA_RawCycles", XamplerSuite.getCommonConstants()[7][1]).trim());
				getBenchmarkExperiment().setSamplesCount(samTestSamples * meaRawCycles);
				
				if (processed.getSections().length > 1) {
					Section runtimeSection = processed.getSections()[1];
					RadiosWithSections radios = (RadiosWithSections) runtimeSection.getItems()[0];
					
					if (radios.getSelectedId().equals("no")) {
						// do not override runtime parameters
						break;
					}
					RadioWithSectionItem selectedSection = radios.getItems()[radios.getSelectedIndex()];
					StringBuilder buf = new StringBuilder();
					for (Item item : selectedSection.getSection().getItems()) {
						Input input = (Input) item;
						buf.append(input.getValue()).append(" ");
					}
					
					if (XamplerSuite.Concurrency_Client_Connections.getName().equals(getBenchmarkExperiment().getProperty("xampler.suite"))) {
						getBenchmarkExperiment().setProperty("xampler.server.params", buf.toString());
					} else {
						getBenchmarkExperiment().setProperty("xampler.client.params", buf.toString());
					}
					
					
				}
				
				
				
				break;
			case SUITE_SUBSELECTION:
				Select subMenu = (Select) processed.getSections()[0].getItems()[0];
				getBenchmarkExperiment().setProperty("xampler.subsuite", subMenu.getSelectedId());
				break;
			case CLIENT_ROLE:
				hostRSL = (RSLInput)processed.getSections()[0].getItems()[0];
				int count = 1;
				if (XamplerSuite.Concurrency_Client_Connections.getName().equals(getBenchmarkExperiment().getProperty("xampler.suite"))) {
					count = Integer.parseInt(getBenchmarkExperiment().getProperty("xampler.server.params","1").trim());
				}
				// by default 1 client
				getBenchmarkExperiment().addBenchmarkingRole(XamplerTaskGenerator.XAMPLER_CLIENT, stringToRSL(hostRSL.getValue()),count);
				break;
			case SERVER_ROLE:
				hostRSL = (RSLInput)processed.getSections()[0].getItems()[0];
				getBenchmarkExperiment().addBenchmarkingRole(XamplerTaskGenerator.XAMPLER_SERVER,stringToRSL(hostRSL.getValue()),1);
				break;
			case COMPILE_ROLE:
				hostRSL = (RSLInput)processed.getSections()[0].getItems()[0];
				getBenchmarkExperiment().addRole(
				XamplerTaskGenerator.SERVER_COMPILE,stringToRSL(hostRSL.getValue()),1);
				break;
		}
		
	}

	/**
	 * Converts RSL string to Condition object
	 * rslString must be validated before using (exception is ignored)
	 */
	private Condition stringToRSL(String rslString) {
		try {
			return ParserWrapper.parseString(rslString);
		} catch (ParseException e) {
			// we never get here as RSLInput is validating
			assert false : "RSL from RSLInput is invalid";
			return null;
		}
	}
	
}
