/*
 *  BEEN: Benchmarking Environment
 *  ==============================
 *
 *  File author: Branislav Repcek
 *
 *  GNU Lesser General Public License Version 2.1
 *  ---------------------------------------------
 *  Copyright (C) 2004-2006 Distributed Systems Research Group,
 *  Faculty of Mathematics and Physics, Charles University in Prague
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License version 2.1, as published by the Free Software Foundation.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 *  MA  02111-1307  USA
 */

package cz.cuni.mff.been.hostmanager.load;

/**
 * Status of the host in the environment.
 *
 * @author Branislav Repcek
 */
public enum HostStatus {

	/**
	 * Host was online during the last check. 
	 */
	ONLINE,
	
	/**
	 * Host was shut down (correct shutdown).
	 */
	OFFLINE,
	
	/**
	 * Host probably crashed since it is not sending data to the LS.
	 */
	CRASHED,
	
	/**
	 * Unknown status.
	 */
	UNKNOWN;
	
	/** String representation of the statuses. */
	private static final String[] STRINGS = {
		"online",
		"offline",
		"crashed",
		"unknown"
	};
	
	/**
	 * Returns a string representation of the object.
	 * 
	 * @return a string representation of the object
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString() {
		return STRINGS[ordinal()];
	}	
}
