/*
 *  BEEN: Benchmarking Environment
 *  ==============================
 *
 *  File author: Jakub Lehotsky
 *
 *  GNU Lesser General Public License Version 2.1
 *  ---------------------------------------------
 *  Copyright (C) 2004-2006 Distributed Systems Research Group,
 *  Faculty of Mathematics and Physics, Charles University in Prague
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License version 2.1, as published by the Free Software Foundation.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 *  MA  02111-1307  USA
 */
package cz.cuni.mff.been.resultsrepository;

import java.net.InetAddress;
import java.rmi.RemoteException;
import java.rmi.server.UnicastRemoteObject;
import java.util.List;

import cz.cuni.mff.been.common.DownloadHandle;
import cz.cuni.mff.been.common.DownloadStatus;
import cz.cuni.mff.been.common.UploadHandle;
import cz.cuni.mff.been.common.UploadStatus;
import cz.cuni.mff.been.common.id.ID;
import cz.cuni.mff.been.resultsrepository.gui.DataFormat;
import cz.cuni.mff.been.resultsrepository.gui.Entity;
import cz.cuni.mff.been.resultsrepository.gui.EntityInterface;
import cz.cuni.mff.been.resultsrepository.gui.GraphType;

public abstract class EntityImplementation<T extends ID> 
	extends UnicastRemoteObject  implements EntityInterface<T> {
	
	/** Reference to results repository database */	
	protected Database database;
	protected Exporter exporter;
	protected Importer importer;
	
	EntityImplementation() throws RemoteException {
		super();
		this.database = Database.getInstance();
		this.exporter = Exporter.getInstance();
		this.importer = Importer.getInstance();
	}

	public abstract Entity<T> getEntity(T id) throws RemoteException;

	public abstract void setEntityComment(T id, String comment) throws RemoteException;

	public abstract List<Entity<T>> getEntities() throws RemoteException;

	public abstract EntityInterface getSubentityInterface(T id) throws RemoteException;

	public abstract DataFormat[] getExportFormats() throws RemoteException;

	public abstract DownloadHandle beginExport(T[] ids, String formatId, InetAddress ip, int port) 
		throws RemoteException, ResultsRepositoryBusyException;

	public DownloadStatus getExportStatus(DownloadHandle handle) throws RemoteException {
		return exporter.getExportStatus(handle);
	}

	public void endExport(DownloadHandle handle) throws RemoteException {
		exporter.endExport(handle);
	}
	public abstract DataFormat[] getImportFormats() throws RemoteException;

	public abstract UploadHandle beginImport(String formatId, InetAddress ip, int port) 
		throws RemoteException, ResultsRepositoryBusyException;

	public UploadStatus getImportStatus(UploadHandle handle) throws RemoteException {
		return importer.getImportStatus(handle);
	}
	public void endImport(UploadHandle handle) throws RemoteException {
		importer.endImport(handle);		
	}
	public abstract void deleteEntity(T id) throws DeleteLockedException, RemoteException;

	public abstract int graphCount(GraphType graphType, T id) throws RemoteException;	

	public abstract DownloadHandle beginGraphDownload(GraphType graphType, T id, InetAddress ip,
			int port, int index) throws RemoteException,
			ResultsRepositoryBusyException, ResultsRepositoryException;

	public DownloadStatus getGraphDownloadStatus(DownloadHandle handle) throws RemoteException {
		return database.getFileDownloadStatus(handle);
	}

	public void endGraphDownload(DownloadHandle handle) throws RemoteException {
		database.endFileDownload(handle);		
	}
	
}
