/*
 *  BEEN: Benchmarking Environment
 *  ==============================
 *
 *  File author: Jakub Lehotsky
 *
 *  GNU Lesser General Public License Version 2.1
 *  ---------------------------------------------
 *  Copyright (C) 2004-2006 Distributed Systems Research Group,
 *  Faculty of Mathematics and Physics, Charles University in Prague
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License version 2.1, as published by the Free Software Foundation.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 *  MA  02111-1307  USA
 */
package cz.cuni.mff.been.resultsrepository;

import cz.cuni.mff.been.common.id.AID;
import cz.cuni.mff.been.common.id.BID;
import cz.cuni.mff.been.common.id.EID;
import cz.cuni.mff.been.common.id.RID;

/**
 * Callback interface used after file is uploaded into Results Repository database.
 * This is used for all functionality needed to be executed after some file is finished with 
 * uploading into Results Repository. Now its used for importing and for making statistical 
 * evaluation after results has been uploaded. 
 * 
 * @author Jakub Lehotsky
 */
public interface FileUploadCallbackInterface {
	
	/**
	 * Implement this function to do, what needs to be done
	 * 
	 * @param data	General data, you can set up to accept it what you want when registering 
	 * 				upload callback.
	 */
	void callbackFunction(Object data);
	
	/**
	 * @return associated Analysis ID
	 */
	AID getAid();

	/**
	 * @return associated Experiment ID
	 */
	EID getEid();
	
	/**
	 * @return associated Binary ID
	 */
	BID getBid();
	
	/**
	 * @return associated Run ID
	 */
	RID getRid();
}
