/*
 *  BEEN: Benchmarking Environment
 *  ==============================
 *
 *  File author: Jakub Lehotsky
 *
 *  GNU Lesser General Public License Version 2.1
 *  ---------------------------------------------
 *  Copyright (C) 2004-2006 Distributed Systems Research Group,
 *  Faculty of Mathematics and Physics, Charles University in Prague
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License version 2.1, as published by the Free Software Foundation.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 *  MA  02111-1307  USA
 */
package cz.cuni.mff.been.resultsrepository;

import java.net.InetAddress;
import cz.cuni.mff.been.common.UploadHandle;

/**
 * Import interface. If you want to make new importing format, you have to implement this interface 
 * and register in the Importer class (for now, change the hardcoded table in Importer.java)
 * 
 *
 * @author Jakub Lehotsky
 */

public interface ImportInterface {

	/**
	 * Notice given import implementation with Results Repository database, importer calls this 
	 * prior to begin{Whatever}Import to notice about database instance to use.
	 * @param aDatabase	Database instance
	 */
	void setDatabase(Database aDatabase);
		
	/**
	 * Begins analyses import, you should implement the recieving of single import package to 
	 * InetAddress ip and port. All the importing functionality should be done via some callback 
	 * function, you should pass this as the argument to <code>database.uploadFile</code> method.
	 * It is called after the file has been uploaded. (see <code>FileUploadCallbackInterface</code>) 
	 * Otherwise this methods works like <code>uploadFile</code> from Database.java, using 
	 * <code>getAnalysesImportStatus</code> nad <code>endAnalysesImportStatus</code> accordingly.
	 * @see cz.cuni.mff.been.resultsrepository.Database#uploadFile 
	 *    
	 * @param ip	ip address to recieve imported package from
	 * @param port	Port to use for network communication
	 * @return		Download handle to use for checking status and finishing import
	 * @throws ResultsRepositoryBusyException
	 */
	UploadHandle beginAnalysesImport(InetAddress ip, int port)
			throws ResultsRepositoryBusyException;
	
	/**
	 * Begins experiments import, you should implement the recieving of single import package to 
	 * InetAddress ip and port. All the importing functionality should be done via some callback 
	 * function, you should pass this as the argument to <code>database.uploadFile</code> method.
	 * It is called after the file has been uploaded. (see <code>FileUploadCallbackInterface</code>) 
	 * Otherwise this methods works like <code>uploadFile</code> from Database.java, using 
	 * <code>getAnalysesImportStatus</code> nad <code>endAnalysesImportStatus</code> accordingly.
	 * @see cz.cuni.mff.been.resultsrepository.Database#uploadFile 
	 *    
	 * @param ip	ip address to recieve imported package from
	 * @param port	Port to use for network communication
	 * @return		Download handle to use for checking status and finishing import
	 * @throws ResultsRepositoryBusyException
	 */
	UploadHandle beginExperimentsImport(InetAddress ip, int port) 
			throws ResultsRepositoryBusyException;
	  
	/**
	 * Begins binaries import, you should implement the recieving of single import package to 
	 * InetAddress ip and port. All the importing functionality should be done via some callback 
	 * function, you should pass this as the argument to <code>database.uploadFile</code> method.
	 * It is called after the file has been uploaded. (see <code>FileUploadCallbackInterface</code>) 
	 * Otherwise this methods works like <code>uploadFile</code> from Database.java, using 
	 * <code>getAnalysesImportStatus</code> nad <code>endAnalysesImportStatus</code> accordingly.
	 * @see cz.cuni.mff.been.resultsrepository.Database#uploadFile 
	 *  
	 * @param ip	ip address to recieve imported package from
	 * @param port	Port to use for network communication
	 * @return		Download handle to use for checking status and finishing import
	 * @throws ResultsRepositoryBusyException
	 */
	UploadHandle beginBinariesImport(InetAddress ip, int port) 
			throws ResultsRepositoryBusyException;
	  		
	/**
	 * Begins runs import, you should implement the recieving of single import package to 
	 * InetAddress ip and port. All the importing functionality should be done via some callback 
	 * function, you should pass this as the argument to <code>database.uploadFile</code> method.
	 * It is called after the file has been uploaded. (see <code>FileUploadCallbackInterface</code>) 
	 * Otherwise this methods works like <code>uploadFile</code> from Database.java, using 
	 * <code>getAnalysesImportStatus</code> nad <code>endAnalysesImportStatus</code> accordingly.
	 * @see cz.cuni.mff.been.resultsrepository.Database#uploadFile 
	 *   
	 * @param ip	ip address to recieve imported package from
	 * @param port	Port to use for network communication
	 * @return		Download handle to use for checking status and finishing import
	 * @throws ResultsRepositoryBusyException
	 */
	UploadHandle beginRunsImport(InetAddress ip, int port) 
			throws ResultsRepositoryBusyException;

}
