/*
 *  BEEN: Benchmarking Environment
 *  ==============================
 *
 *  File author: Jakub Lehotsky
 *
 *  GNU Lesser General Public License Version 2.1
 *  ---------------------------------------------
 *  Copyright (C) 2004-2006 Distributed Systems Research Group,
 *  Faculty of Mathematics and Physics, Charles University in Prague
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License version 2.1, as published by the Free Software Foundation.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 *  MA  02111-1307  USA
 */
package cz.cuni.mff.been.resultsrepository;

import cz.cuni.mff.been.task.Task;


/**
 * Internal logging instance for Results Reposiotry to hide task's logging interface for 
 * purposes of standalone (out-of-task) running of Results Repository. They key purpose
 * is to assure modularity and allow unit testing.
 * 
 * 
 * @author Jakub Lehotsky
 */
public final class Logger {

	
	/** Task we're attached to */
	private static Task task;
	
	/**
	 *  Construction, notify load collector about Results Repository database when constructing
	 */
	private Logger() {
	}
	
	public static void initialize() {
	    task = Task.getTaskHandle();
	}
	
	/**
	 * Logs a message on the DEBUG debug level
	 * @param message
	 */
	public static void logDebug(String message) {
	    if (task == null) {
		System.err.println(message);
	    } else {
		task.logDebug(message);
	    }
	}
	
	/**
	 * Logs a message on the ERROR debug level
	 * @param message
	 */
	public static void logError(String message) {
	    if (task == null) {
		System.err.println(message);
	    } else {
		task.logError(message);
	    }

	}

	/**
	 * Logs a message on the FATAL debug level
	 * @param message
	 */
	public static void logFatal(String message) {
	    if (task == null) {
		System.err.println(message);
	    } else {
		task.logFatal(message);
	    }

	}

	/**
	 * Logs a message on the INFO debug level
	 * @param message
	 */
	public static void logInfo(String message) {
	    if (task == null) {
		System.err.println(message);
	    } else {
		task.logInfo(message);
	    }

	}
	
	/**
	 * Logs a message on the TRACE debug level
	 * @param message
	 */
	public static void logTrace(String message) {
	    if (task == null) {
		System.err.println(message);
	    } else {
		task.logTrace(message);
	    }

	}

	/**
	 * Logs a message on the WARN debug level
	 * @param message
	 */
	public static void logWarning(String message) {
	    if (task == null) {
		System.err.println(message);
	    } else {
		task.logWarning(message);
	    }
	}
}
