/*
 *  BEEN: Benchmarking Environment
 *  ==============================
 *
 *  File author: Jakub Lehotsky
 *
 *  GNU Lesser General Public License Version 2.1
 *  ---------------------------------------------
 *  Copyright (C) 2004-2006 Distributed Systems Research Group,
 *  Faculty of Mathematics and Physics, Charles University in Prague
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License version 2.1, as published by the Free Software Foundation.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 *  MA  02111-1307  USA
 */
package cz.cuni.mff.been.resultsrepository;

import cz.cuni.mff.been.common.id.AID;
import cz.cuni.mff.been.common.id.BID;
import cz.cuni.mff.been.common.id.EID;
import cz.cuni.mff.been.common.id.RID;

/**
 * Data class, that holds information about one event to be executed on Results Repository
 * background thread. It holds information about R script to run or run upload callback
 * to be executed.
 * 
 * @author Jakub Lehotsky
 */

public class RREvent {
	
	/** Analysis event is tied to */
	private AID aid;
	
	/** Experiment event is tied to */
	private EID eid;
	
	/** Binary event is tied to */
	private BID bid;
	
	/** Run event is tied to */
	private RID rid;
	
	/** True if R script, false if callback */  
	private boolean isScript;
	
	/** R call in case of R script */
	private String scriptToRun;
	
	/** Callback object in case of callback */
	private FileUploadCallbackInterface callbackInterface;
	
	/** Callback object data in case of callback */
	private Object callbackData;

	/**
	 * Constructs the event
	 * 
	 * @param aid	Associated analysis Id
	 * @param eid	Associated experiment Id
	 * @param bid	Associated binary Id
	 * @param rid	Associated run Id
	 * @param isScript	
	 * @param scriptToRun
	 * @param callbackInterface
	 * @param callbackData
	 */
	public RREvent(AID aid, EID eid, BID bid, RID rid, boolean isScript, String scriptToRun, 
			FileUploadCallbackInterface callbackInterface, Object callbackData) {
		
		super();
		this.aid = aid;
		this.eid = eid;
		this.bid = bid;
		this.rid = rid;
		this.isScript = isScript;
		this.scriptToRun = scriptToRun;
		this.callbackInterface = callbackInterface;
		this.callbackData = callbackData;
	}

	/**
	 * @return the aid
	 */
	public AID getAid() {
		return aid;
	}
	
	/**
	 * @return the eid
	 */
	public EID getEid() {
		return eid;
	}

	/**
	 * @return the bid
	 */
	public BID getBid() {
		return bid;
	}
	
	/**
	 * @return the rid
	 */
	public RID getRid() {
		return rid;
	}

	/**
	 * @return the rScript
	 */
	public boolean getIsScript() {
		return isScript;
	}

	/**
	 * @return the scriptToRun
	 */
	public String getScriptToRun() {
		return scriptToRun;
	}
	
	/**
	 * @return the callbackInterface
	 */
	public FileUploadCallbackInterface getCallbackInterface() {
		return callbackInterface;
	}

	/**
	 * @return the callbackData
	 */
	public Object getCallbackData() {
		return callbackData;
	}
	
}
