/*
 *  BEEN: Benchmarking Environment
 *  ==============================
 *
 *  File author: Jakub Lehotsky
 *
 *  GNU Lesser General Public License Version 2.1
 *  ---------------------------------------------
 *  Copyright (C) 2004-2006 Distributed Systems Research Group,
 *  Faculty of Mathematics and Physics, Charles University in Prague
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License version 2.1, as published by the Free Software Foundation.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 *  MA  02111-1307  USA
 */
package cz.cuni.mff.been.resultsrepository;

import java.io.Serializable;

import cz.cuni.mff.been.common.id.RID;

/**
 * Class containing one single information about one item of the validity maps table
 *
 * @author Jakub Lehotsky
 */
public class RRIDItem implements Serializable {
	
	/** Item key - numerical index - RID */
	private RID key;
	/** File names */	
	private String fileName;
	/** Indicates validity of given run */
	private boolean valid;
	/** Host index */
	private long hostIndex;

	/**
	 * Allocates a new <code>MetadataItem</code> object.
	 * 
	 * @param key metadata key
	 * @param validity validity of run
	 * @param fileName The name of the file to store data in
	 * @param hostIndex	Index of the host
	 */
	public RRIDItem(RID key, boolean validity, String fileName, long hostIndex) {
	    this.key = key;
	    this.fileName = fileName;
	    this.valid = validity;
	    this.hostIndex = hostIndex;
	}
	
	/** @return the key */
	public RID getKey() {
	    return key;
	}

	/** @return the name of all tables */
	public String getTableName() {
	    return fileName;
	}
	
	/** @return validity of run */
	public boolean getValid() {
	    return valid;
	}
	
	/** @return index of the host */
	public long getHostIndex() {
		return hostIndex;
	}
	
	/**
	 * Sets the filename of the file
	 * 
	 * @param filename
	 */
	public void setTableName(String filename) {
		this.fileName = filename;
	}

	/**
	 * Returns just the run index of the filename of table
	 * 
	 * @return	The run index
	 */
	public String getIndexOfTable() {
		
		int placeToCut = fileName.indexOf("-");
		
		if (placeToCut == -1) {
			Logger.logWarning("Reference to run file possibly corrupted - " + fileName);
			return fileName;
		}
		
		return fileName.substring(0, placeToCut);
	}
	
}
