/*
 *  BEEN: Benchmarking Environment
 *  ==============================
 *
 *  File author: Jakub Lehotsky
 *
 *  GNU Lesser General Public License Version 2.1
 *  ---------------------------------------------
 *  Copyright (C) 2004-2006 Distributed Systems Research Group,
 *  Faculty of Mathematics and Physics, Charles University in Prague
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License version 2.1, as published by the Free Software Foundation.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 *  MA  02111-1307  USA
 */
package cz.cuni.mff.been.resultsrepository.test;

import java.net.MalformedURLException;
import java.rmi.Naming;
import java.rmi.NotBoundException;
import java.rmi.Remote;
import java.rmi.RemoteException;

import cz.cuni.mff.been.benchmarkmanager.AnalysisEntity;
import cz.cuni.mff.been.benchmarkmanager.AnalysisMetadata;
import cz.cuni.mff.been.benchmarkmanager.BinaryEntity;
import cz.cuni.mff.been.benchmarkmanager.ExperimentEntity;
import cz.cuni.mff.been.benchmarkmanager.ExperimentMetadata;
import cz.cuni.mff.been.common.id.AID;
import cz.cuni.mff.been.common.id.BID;
import cz.cuni.mff.been.common.id.EID;
import cz.cuni.mff.been.common.id.PEID;
import cz.cuni.mff.been.resultsrepository.ResultsRepositoryDebugInterface;
import cz.cuni.mff.been.resultsrepository.ResultsRepositoryException;
import cz.cuni.mff.been.resultsrepository.ResultsRepositoryInterface;

public class TestCreateEntities {

	private Remote getResultsRepositoryIface(String iface) {
		// try to obtain reference ASAP and do nothing if we fail to get it
		Remote resultsRepository = null;
		try {
			resultsRepository = Naming.lookup(iface);
		} catch (MalformedURLException e) {
			e.printStackTrace();
		} catch (RemoteException e) {
			e.printStackTrace();
		} catch (NotBoundException e) {
			e.printStackTrace();
		}
	
		return resultsRepository;
	}

	private void run() {
		System.out.println("Getting results repository RMI reference ... ");
		ResultsRepositoryInterface rrInstance = 
			(ResultsRepositoryInterface) getResultsRepositoryIface("been/resultsrepository/main");
		ResultsRepositoryDebugInterface rrDebugInstance = 
			(ResultsRepositoryDebugInterface) getResultsRepositoryIface("been/resultsrepository/debug");
		
		try {
			
			AnalysisMetadata analysisMetadata = new AnalysisMetadata(new AID(12));
			analysisMetadata.setName("Analysis 12");
			analysisMetadata.setDescription("Description of analysis 12");
			rrInstance.addAnalysis(new AnalysisEntity(analysisMetadata));
			
			ExperimentMetadata experimentMetadata = new ExperimentMetadata(new AID(12), new EID(36),
					"Experiment 36", "Description of exp. 36", new PEID("<Plugin name>"),
					"<Plugin name>");
			experimentMetadata.setBinaryCount(1);
			experimentMetadata.setRunCount(3);
			experimentMetadata.setSamplesCount(50000);
						
			
			
			experimentMetadata.getTaskSequence().openBinary(new BID(48));
			experimentMetadata.getTaskSequence().closeBinary();
			
			rrInstance.addExperiment(new ExperimentEntity(experimentMetadata));
			rrInstance.addBinary(new BinaryEntity(experimentMetadata, new BID(48)));
			
			rrDebugInstance.enqueueScriptExecution(null, null, "beendemo.notifyAlive()");
			
			
			
		} catch (ResultsRepositoryException e) {
			e.printStackTrace();
		} catch (RemoteException e) {
			e.printStackTrace();
		}
	}

	public static void main(String[] argv) {
	
		TestCreateEntities instance = new TestCreateEntities();
		instance.run();
	
	}

}
