/*
 *  BEEN: Benchmarking Environment
 *  ==============================
 *
 *  File author: Michal Tomcanyi
 *
 *  GNU Lesser General Public License Version 2.1
 *  ---------------------------------------------
 *  Copyright (C) 2004-2006 Distributed Systems Research Group,
 *  Faculty of Mathematics and Physics, Charles University in Prague
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License version 2.1, as published by the Free Software Foundation.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 *  MA  02111-1307  USA
 */
package cz.cuni.mff.been.task.download;

import org.netbeans.lib.cvsclient.event.CVSAdapter;
import org.netbeans.lib.cvsclient.event.MessageEvent;

import cz.cuni.mff.been.common.StringUtils;
import cz.cuni.mff.been.task.Task;


public class LoggingCVSListener extends CVSAdapter {
	/** Stores a tagged line */
	@SuppressWarnings("unused") // TODO tomcanyi: temporary warning fix
	private final StringBuffer taggedLine = new StringBuffer();
	/** Task through which to log messages */
	private final Task owningTask;
	
	public LoggingCVSListener(Task owningTask) {
		this.owningTask = owningTask;
	}
	
	
	/**
	 * Called when the server wants to send a message to be displayed to
	 * the user. The message is only for information purposes and clients
	 * can choose to ignore these messages if they wish.
	 * @param msgEvent the event
	 */
	public void messageSent(MessageEvent msgEvent) {
		String line = msgEvent.getMessage();

		if (msgEvent.isTagged()) {
			String message = MessageEvent.parseTaggedMessage(
					new StringBuffer(), msgEvent.getMessage());
			// if we get back a non-null line, we have something
			// to output. Otherwise, there is more to come and we
			// should do nothing yet.
			if (!StringUtils.isEmpty(message)) {
				owningTask.logInfo(message);
			}
		} else {
			owningTask.logInfo(line);
		}
	}
}
