/*
 * Created on Nov 5, 2006
 *
 * BEEN
 * @author Jaroslav Urban
 */
package cz.cuni.mff.been.task.jboss.build;

import java.io.File;
import java.util.ArrayList;
import java.util.Map;

import cz.cuni.mff.been.common.ArrayUtils;
import cz.cuni.mff.been.common.OutputReader;
import cz.cuni.mff.been.common.OutputType;
import cz.cuni.mff.been.task.Job;
import cz.cuni.mff.been.task.TaskException;
import cz.cuni.mff.been.task.TaskInitializationException;

/**
 * <p>Compiles JBoss from it's source.</p>
 *
 * <b>Task properties:</b><br>
 * <ul>
 * <li>{@value #JBOSS_DIR}: <br>
 * 		- path to the JBoss source code <br>
 * 		- mandatory <br>
 * </ul>
 * 
 * @author Jaroslav Urban
 */
public class JBossBuild extends Job {
	/** Task property name for the JBoss installation directory. */
	public static final String JBOSS_DIR = "jboss.dir";

	/** JBoss installation directory. */
	private String jbossDir;


	/**
	 * Allocates a new <code>JBossBuild</code> object.
	 *
	 * @throws TaskInitializationException
	 */
	public JBossBuild() throws TaskInitializationException {
		super();
	}


	/* (non-Javadoc)
	 * @see cz.cuni.mff.been.task.Job#checkRequiredProperties()
	 */
	@Override
	protected void checkRequiredProperties() throws TaskException {
		checkRequiredProperties(new String[]{JBOSS_DIR});
	}


	/* (non-Javadoc)
	 * @see cz.cuni.mff.been.task.Job#run()
	 */
	@Override
	protected void run() throws TaskException {
		jbossDir = getTaskProperty(JBOSS_DIR);
		logInfo("JBoss directory: " + jbossDir);

		ArrayList<String> params = new ArrayList<String>();
		if (isRunningInWindows()) {
			params.add("cmd");
			params.add("/C");
			params.add("call");
			params.add(jbossDir + File.separator + "build" + File.separator 
					+ "build.bat");
		}
		if (isRunningInLinux()) {
			params.add(jbossDir + File.separator + "build" + File.separator 
					+ "build.sh");
		}
		// set the install.id property to jboss so that the compile
		// output is always in the same directory
		params.add("-Dinstall.id\"=\"jboss");
		String[] cmdArray = params.toArray(new String[params.size()]);
		
		try {
			logInfo("Compiling JBoss");
			logInfo("Executing: " + ArrayUtils.join(" ", cmdArray));
			
			ProcessBuilder builder = new ProcessBuilder(cmdArray);
			builder.directory(new File(jbossDir, "build"));
			Process p = builder.start();
			p.getOutputStream().close();
			
			/* Read in the output from the subprocess */
			OutputReader stdoutReader = 
				new OutputReader(p.getInputStream(), OutputType.STDOUT);
			OutputReader stderrReader = 
				new OutputReader(p.getErrorStream(), OutputType.STDERR);
			stdoutReader.start();
			stderrReader.start();

			// wait untill the compilation finishes
			if (p.waitFor() != 0) {
				throw new TaskException("Build failed");
			}
		} catch (TaskException e) {
			throw e;
		} catch (Exception e) {
			throw new TaskException("Cannot run JBoss compilation", e);
		}
		
		logInfo("Build succesfull");
	}
}
