/*
 *  BEEN: Benchmarking Environment
 *  ==============================
 *
 *  File author: Jakub Lehotsky
 *
 *  GNU Lesser General Public License Version 2.1
 *  ---------------------------------------------
 *  Copyright (C) 2004-2006 Distributed Systems Research Group,
 *  Faculty of Mathematics and Physics, Charles University in Prague
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License version 2.1, as published by the Free Software Foundation.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 *  MA  02111-1307  USA
 */
package cz.cuni.mff.been.task.results;

import cz.cuni.mff.been.common.id.BID;
import cz.cuni.mff.been.common.id.RID;

/**
 * Helper class to hold information about one item of run data to upload
 * 
 * @author Jakub Lehotsky
 */
class RunResultsPosition {
		/**
		 * Binary identification (analysis and experiment used from
		 * XamplerResultsCollectionTask class)
		 */
		private BID bid;

		/** Index of run */
		private RID rid;

		/** TID of task which holds run results */
		private String runPath;

		/**
		 * Initialization of position of results of one run
		 * 
		 * @param bid	BinaryID
		 * @param rid 	RunID
		 * @param runPath Path to results from run identified by bid, rid
		 */
		public RunResultsPosition(BID bid, RID rid, String runPath) {
			super();

			this.bid = bid;
			this.rid = rid;			
			this.runPath = runPath;
		}

		/**
		 * @return Returns the bid.
		 */
		public BID getBid() {
			return bid;
		}

		/**
		 * @return Returns the rid.
		 */
		public RID getRid() {
			return rid;
		}

		/**
		 * Returns the path of task stored
		 * @return The path of task
		 */
		public String getPath() {
			return runPath;			
		}
	}
