package cz.cuni.mff.been.webinterface;

import java.rmi.RemoteException;
import java.util.HashMap;
import java.util.Map;

import cz.cuni.mff.been.taskmanager.CheckPoint;
import cz.cuni.mff.been.taskmanager.TaskManagerException;
import cz.cuni.mff.been.taskmanager.TaskManagerInterface;
import cz.cuni.mff.been.taskmanager.data.TaskEntry;

/**
 * Class containing utility functions for working with tasks. These functions
 * are used in several modules of the web interface.
 * 
 * @author David Majda
 */
public class TaskUtils {
	/**
	 * Get checkpoints for a list of tasks.
	 * 
	 * @param taskManager Task Manager interface RMI reference
	 * @param tasks list of tasks for which to get the checkpoints
	 * @return map, mapping <code>TaskEntry</code> objects representing the tasks
	 *          to the arrays of <code>CheckPoint</code> objects representing
	 *          checkpoints the task reached
	 * @throws RemoteException if the RMI call to the Task Manager fails
	 */
	public static Map<TaskEntry, CheckPoint[]> getCheckPointsForTasks(
			TaskManagerInterface taskManager, TaskEntry[] tasks)
			throws RemoteException { 
		Map<TaskEntry, CheckPoint[]> result = new HashMap<TaskEntry, CheckPoint[]>();
		for (TaskEntry task: tasks) {
			try {
				result.put(task, taskManager.checkPointLook(
						new CheckPoint(task.getTaskId(), task.getContextId(), null, null),
						0
				));
			} catch (TaskManagerException e) {
				result.put(task, new CheckPoint[0]);
			}
		}
		return result;
	}

	/**
	 * Private construcor is so no instances can be created.
	 */
	private TaskUtils() {
	}
}
