package cz.cuni.mff.been.webinterface.benchmarks;

import java.util.Arrays;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;

import cz.cuni.mff.been.benchmarkmanager.BinaryEntity;
import cz.cuni.mff.been.benchmarkmanager.EntityStatus;
import cz.cuni.mff.been.common.id.BID;
import cz.cuni.mff.been.taskmanager.CheckPoint;
import cz.cuni.mff.been.taskmanager.data.TaskEntry;
import cz.cuni.mff.been.taskmanager.data.TaskState;

/**
 * Wrapper class for the binary entity in the Benchmark Manager.
 * 
 * @author David Majda
 */
public class Binary {
	/** Wrapped entity. */
	private BinaryEntity entity;
	/** Runs in wrapped binary. */ 
	private Run[] runs;
	/** Tasks in wrapped binary. */
	private TaskEntry[] tasks;
	/** Reached checkpoints of tasks in this binary. */ 
	private Map<TaskEntry, CheckPoint[]> checkpoints;
	
	/** @return binary identifier */
	public BID getId() {
		return entity.getId();
	}

	/** @return binary name */
	public String getName() {
		return entity.getName();
	}

	/** @return binary status */
	public EntityStatus getStatus() {
		return entity.getStatus();
	}

	/** @return number of tasks in this binary and contained runs */
	public int aggregatedTaskCount() {
		int result = tasks.length;
		for (Run run: runs) {
			result += run.taskCount();
		}
		return result;
	}
	
	/** @return number of finished tasks in this binary and contained runs */
	public int aggregatedFinishedTaskCount() {
		int result = 0;
		for (TaskEntry task: tasks) {
			if (task.getState().equals(TaskState.FINISHED)) {
				result++;
			}
		}
		for (Run run: runs) {
			result += run.finishedTaskCount();
		}
		return result;
	}

	/** @return number of runs in this binary */
	public int runCount() {
		return runs.length;
	}

	/** @return runs in this binary */
	public Run[] getRuns() {
		return runs;
	}
	
	/** @return tasks in this binary  */
	public TaskEntry[] getTasks() {
		return tasks;
	}

	/** @return tasks in this binary and contained runs */
	public TaskEntry[] getAggregatedTasks() {
		List<TaskEntry> result = new LinkedList<TaskEntry>();
		result.addAll(Arrays.asList(tasks));
		for (Run run: runs) {
			result.addAll(Arrays.asList(run.getTasks()));
		}
		return result.toArray(new TaskEntry[result.size()]);
	}

	/** @return reached checkpoints of tasks in this binary */
	public Map<TaskEntry, CheckPoint[]> getCheckpoints() {
		return checkpoints;
	}

	/**
	 * Allocates a new <code>Run</code> object.
	 * 
	 * @param entity wrapped entity
	 * @param runs runs in this binary
	 * @param tasks tasks in this binary
	 * @param checkpoints reached checkpoints of tasks in this binary
	 */
	public Binary(BinaryEntity entity, Run[] runs, TaskEntry[] tasks,
			Map<TaskEntry, CheckPoint[]> checkpoints) {
		this.entity = entity;
		this.runs = runs;
		this.tasks = tasks;
		this.checkpoints = checkpoints;
	}
}
