package cz.cuni.mff.been.webinterface.benchmarks;

import java.util.Map;

import cz.cuni.mff.been.benchmarkmanager.EntityStatus;
import cz.cuni.mff.been.benchmarkmanager.RunEntity;
import cz.cuni.mff.been.common.id.RID;
import cz.cuni.mff.been.taskmanager.CheckPoint;
import cz.cuni.mff.been.taskmanager.data.TaskEntry;
import cz.cuni.mff.been.taskmanager.data.TaskState;

/**
 * Wrapper class for the run entity in the Benchmark Manager.
 * 
 * @author David Majda
 */
public class Run {
	/** Wrapped entity. */
	private RunEntity entity;
	/** Tasks in this run. */
	private TaskEntry[] tasks;
	/** Reached checkpoints of tasks in this run. */ 
	private Map<TaskEntry, CheckPoint[]> checkpoints;

	/** @return run identifier */
	public RID getId() {
		return entity.getId();
	}
	
	/** @return run name */
	public String getName() {
		return entity.getName();
	}

	/** @return run status */
	public EntityStatus getStatus() {
		return entity.getStatus();
	}

	/** @return number of tasks in this run */
	public int taskCount() {
		return tasks.length;
	}
	
	/** @return number of finished tasks in this run */
	public int finishedTaskCount() {
		int result = 0;
		for (TaskEntry task: tasks) {
			if (task.getState().equals(TaskState.FINISHED)) {
				result++;
			}
		}
		return result;
	}
	
	/** @return tasks in this run */
	public TaskEntry[] getTasks() {
		return tasks;
	}
	
	/** @return reached checkpoints of tasks in this run */ 
	public Map<TaskEntry, CheckPoint[]> getCheckpoints() {
		return checkpoints;
	}

	/**
	 * Allocates a new <code>Run</code> object.
	 * 
	 * @param entity wrapped run
	 * @param tasks tasks in this run
	 * @param checkpoints reached checkpoints of tasks in this run 
	 */
	public Run(RunEntity entity, TaskEntry[] tasks,
			Map<TaskEntry, CheckPoint[]> checkpoints) {
		this.entity = entity;
		this.tasks = tasks;
		this.checkpoints = checkpoints;
	}
}
